@@ -4,7 +4,7 @@
 
 //addable
 template <typename Type>
-concept bool Addable =
+concept Addable =
     requires(Type par)
     {
         ++par;          // `Type' variables must support
@@ -16,12 +16,12 @@ concept bool Addable =
     };
 //=
 
+//        typename Type::value_type;
 //index
 template <typename Type>
-concept bool HasIndex =
+concept HasIndex =
     requires(Type tp)
     {
-        typename Type::value_type;
         tp[0];
     };
 
@@ -32,6 +32,19 @@ auto idx(Type const &obj, size_t idx)
 }
 //=
 
+template <typename Type>
+concept HasStrIndex =
+    requires(Type tp)
+    {
+        tp[std::string{}];
+    };
+
+template <HasStrIndex Type>
+auto value(Type &obj, std::string const &key)
+{
+    return obj[key];
+}
+
 using namespace std;
 
 int main()
@@ -39,4 +52,7 @@ int main()
 //    idx(1, 2);
     string str;
     cout << idx(str, 1) << endl;
+
+    map<string, double> msd;
+    value(msd, "hi");
 }
