@@ -5,7 +5,7 @@ using namespace std;
 
 int main()
 {
-    typedef std::tuple<int, double &, std::string, char const *> tuple_idsc;
+    using tuple_idsc = std::tuple<int, double &, std::string, char const *> ;
 
     double pi = 3.14;
     tuple_idsc idsc(59, pi, "hello", "fixed");
