@@ -18,8 +18,8 @@ class CirQue
 
     public:
 //TYPEDEFS
-    typedef Data value_type;
-    typedef value_type const &const_reference;
+    using value_type = Data;
+    using const_reference = const &value_type;
 //=
 
 //EXCEPTION
