@@ -7,18 +7,18 @@
 template<typename Data>
 class CirQue<std::vector<Data>>
 {
-    typedef std::vector<Data> DataVect;
+    using DataVect = std::vector<Data>;
 
     DataVect d_data;
     size_t d_size;
 
-    typedef typename DataVect::iterator iterator;
+    using iterator = typename DataVect::iterator;
     iterator d_front;
     iterator d_back;
 
     public:
-        typedef Data value_type;
-        typedef value_type const &const_reference;
+        using value_type = Data;
+        using value_type = const &const_reference;
 
         enum Exception
         {
