@@ -7,18 +7,18 @@
 template<>
 class CirQue<std::vector<int>>
 {
-    typedef std::vector<int> IntVect;
+    using IntVect =  std::vector<int>;
 
     IntVect d_data;
     size_t d_size;
 
-    typedef IntVect::iterator iterator;
+    using iterator = IntVect::iterator;
     iterator d_front;
     iterator d_back;
 
     public:
-        typedef int value_type;
-        typedef value_type const &const_reference;
+        using value_type = int;
+        using const_reference = const &value_type;
 
         enum Exception
         {
