@@ -3,6 +3,6 @@
 
 #include <cstddef>
 #include <tuple>
-typedef std::tuple<size_t, size_t, size_t> Triplet;
+using Triplet = std::tuple<size_t, size_t, size_t>;
 
 #endif
