@@ -14,12 +14,12 @@ struct Start
         Awaiter await_transform(Next<Handler> &&next);
     };
 
-    typedef std::coroutine_handle<State> Handle;
+    using Handle = std::coroutine_handle<State>;
 
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Start(Handle handle);
         ~Start();
