@@ -1,27 +1,24 @@
     #include <iostream>
+    #include <climits>
     using namespace::std;
 
     int main()
     {
-        cin.exceptions(ios::failbit);
-
+        cin.exceptions(ios::failbit);   // throw exception on fail
         while (true)
         {
             try
             {
                 cout << "enter a number: ";
-
                 int value;
-
                 cin >> value;
-                cout << "you entered " << value << endl;
+                cout << "you entered " << value << '\n';
             }
             catch (ios::failure const &problem)
             {
-                cout << problem.what() << endl;
+                cout << problem.what() << '\n';
                 cin.clear();
-                string s;
-                getline(cin, s);
+                cin.ignore(INT_MAX, '\n');  // ignore the faulty line
             }
         }
     }
