@@ -22,21 +22,21 @@
             };
 
         inplace_merge(range, range + 4, range + 7);
-        copy(range, range + 7, ostream_iterator<string>(cout, " "));
+        copy(range, range + 7, ostream_iterator<string>{ cout, " " });
         cout << '\n';
 
         string range2[] =
             {
-                "ALFA", "CHARLEY", "DELTA", "foxtrot", "hotel",
+                "ALPHA", "CHARLEY", "DELTA", "foxtrot", "hotel",
                 "bravo", "ECHO", "GOLF"
             };
 
-        inplace_merge(range2, range2 + 5, range2 + 8, CaseString());
-        copy(range2, range2 + 8, ostream_iterator<string>(cout, " "));
+        inplace_merge(range2, range2 + 5, range2 + 8, CaseString{});
+        copy(range2, range2 + 8, ostream_iterator<string>{ cout, " " });
         cout << '\n';
     }
     /*
         Displays:
             alpha bravo charley delta echo foxtrot golf
-            ALFA bravo CHARLEY DELTA ECHO foxtrot GOLF hotel
+            ALPHA bravo CHARLEY DELTA ECHO foxtrot GOLF hotel
     */
