@@ -17,7 +17,7 @@
                     count_if
                     (
                         words, words + size,
-                        bind2nd(equal_to<string>(), string("alpha"))
+                        bind2nd(equal_to<string>(), "alpha"s)
                     )
                 ];
         string *returnvalue =
