@@ -11,7 +11,7 @@
                 "oscar", "alpha", "alpha", "papa" };
         size_t const size = sizeof(words) / sizeof(string);
 
-        replace(words, words + size, string("alpha"), string("ALPHA"));
+        replace(words, words + size, "alpha"s, "ALPHA"s);
         copy(words, words + size, ostream_iterator<string>(cout, " "));
         cout << '\n';
     }
