@@ -5,7 +5,7 @@
 
     int main()
     {
-        unique_ptr<string> sp(new string("Hello world"));
+        unique_ptr<string> sp{ new string{ "Hello world" } };
 
         cout << *sp << '\n';
         sp->insert(strlen("Hello "), "C++ ");
