@@ -13,7 +13,7 @@ int main()
     string target("this value 1024 is interesting");
 
     regex_replace(ostream_iterator<char>(cout, ""), target.begin(),
-                    target.end(), re, string("$2"));
+                    target.end(), re, "$2"s);
 //=
     cout << '\n';
 }
