@@ -1,4 +1,4 @@
-// g++ --std=c++0x -pthread events.cc
+// g++ -pthread events.cc
 
 #include <mutex>
 #include <condition_variable>
@@ -10,7 +10,8 @@
     class Semaphore
     {
 //data
-std::mutex d_mutex;
+mutable std::mutex d_mutex;     // mutable because of its use in
+                                // 'size_t size() const'
 std::condition_variable d_condition;
 size_t d_available;
 //=
