@@ -3,7 +3,7 @@
 //code
 Result compile(string const &line)
 {
-    string command("/usr/bin/g++ -Wall --std=c++11 -c " + line);
+    string command("/usr/bin/g++ -Wall -c " + line);
 
     CmdFork cmdFork(command);
     cmdFork.fork();
