@@ -3,5 +3,5 @@
 for x in `cat $1`
 do
     echo $x
-    g++ --std=c++11 -c $x
+    g++ -Wall -c $x
 done
